"""
    Module containing functions for controlling the Oscilloscope
"""

# import modules, constants and types
import dwfconstants as dwfct
import ctypes as ctp
import time

# these will be initialized in the main program
dwf = None
hdwf = None


class state:
    # instrument parameters
    sampling_frequency = 1000000.0
    buffer_size = 8192


def initialize():
    # initialize the oscilloscope
    # set sampling frequency
    dwf.FDwfAnalogInFrequencySet(hdwf, ctp.c_double(state.sampling_frequency))
    # set buffer size
    dwf.FDwfAnalogInBufferSizeSet(hdwf, ctp.c_int(state.buffer_size))
    # enable both channels
    dwf.FDwfAnalogInChannelEnableSet(hdwf, ctp.c_int(-1), ctp.c_bool(True))
    # set range from -5 to +5 V
    dwf.FDwfAnalogInChannelRangeSet(hdwf, ctp.c_int(-1), ctp.c_double(5))
    # store every n-th conversion (don't average)
    dwf.FDwfAnalogInChannelFilterSet(hdwf, ctp.c_int(-1), dwfct.filterDecimate)
    # turn off the trigger
    dwf.FDwfAnalogInTriggerSourceSet(hdwf, dwfct.trigsrcNone)
    time.sleep(2)
    return


def acquisition(channel):
    # data acquisition
    sts = ctp.c_byte()
    rgdSamples = (ctp.c_double*state.buffer_size)()
    # start acquisition
    dwf.FDwfAnalogInConfigure(hdwf, ctp.c_int(1), ctp.c_int(1))
    while True:
        # wait for it to finish
        dwf.FDwfAnalogInStatus(hdwf, ctp.c_int(1), ctp.byref(sts))
        if sts.value == dwfct.DwfStateDone.value:
            break
    # get data
    dwf.FDwfAnalogInStatusData(
        hdwf, channel - 1, rgdSamples, state.buffer_size)
    return rgdSamples
