"""
    Module containing functions for controlling the Waveform Generator
"""

# import modules, constants and types
import dwfconstants as dwfct
import ctypes as ctp
import time

# these will be initialized in the main program
dwf = None
hdwf = None


class state:
    # instrument parameters
    sampling_frequency = 1000000.0
    buffer_size = 8192
    frame_repeat = 1


def initialize():
    # initialize the instrument
    frequency = state.sampling_frequency / (1.0 * state.buffer_size)
    # enable wavegen
    dwf.FDwfAnalogOutNodeEnableSet(
        hdwf, ctp.c_int(-1), dwfct.AnalogOutNodeCarrier, ctp.c_bool(True))
    dwf.FDwfAnalogOutNodeFunctionSet(
        hdwf, ctp.c_int(-1), dwfct.AnalogOutNodeCarrier, dwfct.funcCustom)
    # set frequency
    dwf.FDwfAnalogOutNodeFrequencySet(
        hdwf, ctp.c_int(-1), dwfct.AnalogOutNodeCarrier, ctp.c_double(frequency))
    # set run time
    dwf.FDwfAnalogOutRunSet(hdwf, ctp.c_int(-1), ctp.c_double(1.0 / frequency))
    # turn off wait
    dwf.FDwfAnalogOutWaitSet(hdwf, ctp.c_int(-1), ctp.c_double(0))
    # set repeat times
    dwf.FDwfAnalogOutRepeatSet(
        hdwf, ctp.c_int(-1), ctp.c_int(state.frame_repeat))
    return


def generate(signal, amplitude):
    # generate a signal
    # load the buffer
    dwf.FDwfAnalogOutNodeDataSet(hdwf, ctp.c_int(-1), dwfct.AnalogOutNodeCarrier,
                                 (ctp.c_double * len(signal))(*signal), ctp.c_int(len(signal)))
    # set the amplitude
    dwf.FDwfAnalogOutNodeAmplitudeSet(
        hdwf, ctp.c_int(-1), dwfct.AnalogOutNodeCarrier, ctp.c_double(amplitude))
    # start generation
    dwf.FDwfAnalogOutConfigure(hdwf, ctp.c_int(-1), ctp.c_int(1))
    return
